Using the CKEditor Read-Only API — CKEditor Sample
Description: Try the latest sample of CKEditor 4 and learn more about customizing your WYSIWYG editor with endless possibilities.

# CKEditor Samples » Using the CKEditor Read-Only API

This sample is not maintained anymore. Check out its brand new version in CKEditor Examples.

This sample shows how to use the `setReadOnly` API to put editor into the read-only state that makes it impossible for users to change the editor contents.

For details on how to create this setup check the source code of this sample page.

<p>This is some <strong>sample text</strong>. You are using <a href="https://ckeditor.com/">CKEditor</a>.</p>